@@ -3,9 +3,7 @@ package create
 import (
 	"github.com/weaveworks/eksctl/pkg/ctl/cmdutils"
 
-	. "github.com/onsi/ginkgo/extensions/table"
-
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 )
 
